@@ -2,12 +2,12 @@
 Date         : 2023-11-02 12:44:48
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-11-03 11:31:27
+LastEditTime : 2023-11-13 12:47:53
 LastEditors  : BDFD
 Description  : 
-FilePath     : \execdata\analysis_graph\__init__.py
+FilePath     : \execdata\graph\__init__.py
 Copyright (c) 2023 by BDFD, All Rights Reserved. 
 '''
 
-from ._data_analysis_graph import top_correlation
+from ._data_analysis_graph import discrete_feature_graph, top_correlation
 from ._data_mining_graph import missing_value_analysis
